numina.frame — Frame manipulation — Numina 0.20.dev0 documentation

# `numina.frame` — Frame manipulation

FITS header schema and validation.

This module is a simplification of the FITS Schema defined by Erik Bray here: http://embray.github.io/PyFITS/schema/users_guide/users_schema.html

If this schema implementation reaches pyfits/astropy stable, we will use it instead of ours, with schema definitions being the same.

class `numina.frame.schema.` `Schema`(sc)

  A FITS schema

exception `numina.frame.schema.` `SchemaDefinitionError`

  Exception raised when a FITS Schema definition is not valid.

class `numina.frame.schema.` `SchemaKeyword`(name, mandatory=False, valid=True, value=None)

  A keyword in the schema

exception `numina.frame.schema.` `SchemaValidationError`

  Exception raised when a Schema does not validate a FITS header.